/** 
 *   Air mass at given zenith distance
 *
 *   (c) Copyright 2005 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

/**
 * R.H. Hardie, 1962, `Photoelectric Reductions', Chapter 8 of
 * Astronomical Techniques, W.A. Hiltner (Ed), Stars and Stellar
 * Systems, II (University of Chicago Press: Chicago), pp178-208.  
 **/


#include <math.h>
#include <stdlib.h>

#define MIN(a,b) ((a) <= (b) ? (a) : (b))

double airmas(double z)
{	                               /* 1.52 rad ~ 87 deg */
	double seczm1 = 1.0 / ( cos( MIN( 1.52, fabs( z ) ) ) ) - 1.0;
	return 1.0 + seczm1 * 
		(0.9981833 - seczm1 * (0.002875 + 0.0008083 * seczm1));
}



